==> claws-mail-3.13.1-1-aarch64.pkg.tar.xz: usr/include/claws-mail/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Andrej Kacian <andrej@kacian.sk>",
"Darko Koruga <darko@users.sf.net>",
"Charles Lehner <charles@claws-mail.org>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Paweł Pękala <c0rn@o2.pl>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Hoà Viêt Dinh",
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Werner Koch",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[ca] Carles Tubio Terrón <c@rles-tub.io>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[de] Thomas Bellmann <ThomasBellmann@gmx.net>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"     Carles Tubio Terrón <c@rles-tub.io>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"[he] Isratine Citizen <genghiskhan@gmx.ca>",
"[hu] Páder Rezső <rezso@rezso.net>",
"[it] Luigi Votta <luigi.vtt@gmail.com>",
"[lt] Mindaugas Baranauskas <embar@super.lt>",
"[nb] Petter Adsen <petter@synth.no>",
"[nl] Marcel Pol <mpol@gmx.net>",
"[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
"[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
"[zh_TW] Mark Chang <mark.cyj@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Paweł Pękala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urošević <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"André Filipe de Assunção e Brito",
"Sergei Astanin",
"Ruslan N. Balkin",
"Andy Balaam",
"Henri Bauer",
"Didier Barvaux",
"Fabio Júnior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Sébastien Bigaret",
"Laurent Bigonville",
"Jean-Luc Biord",
"Blatinox",
"Pavlo Bohmat",
"H. Merijn Brand",
"Eugene Brevdo",
"Sean Buckheister",
"Anton Butanaev",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Natanael Copa",
"Jonathan Corbet",
"Christian Cornelssen",
"Palmer Dabbelt",
"George Danchev",
"Robert David",
"Kevin Day",
"Matthieu Dazy",
"Ben Deering",
"Pierric Descamps",
"Rodrigo Dias Arruda Senra",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Mikhail Efremov",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Tiago Faria",
"Alessandro Di Federico",
"Lars Persson Fink",
"Bob Forsman",
"Matthias Förste",
"Ivan Francolin Martinez",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Thierry Godefroy",
"Alex Gorbachenko",
"Michał Górny",
"Bodo Graumann",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Christian Hesse",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Richard Hughes",
"Arthur Huillet",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Daniel Jakots",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"kazken3",
"WAKAI Kazunao",
"Fabian Keil",
"Martin Kluge",
"IWAMOTO Kouichi",
"Mikhail Kurinnoi",
"Abhay S. Kushwaha",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"Reed Loden",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Igor Mammedov",
"Tim Mann",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"Yotam Medini",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"Hanno Meyer-Thurow",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Gustavo Noronha Silva",
"Ales Nosek",
"Emilian Nowak",
"James Noyes",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Miquel Oliete",
"Paul Ollis",
"Fredrik Olofssen",
"Reza Pakdel",
"Richard Palo",
"Marcel Pol",
"Martin Pool",
"Quar",
"Don Quijote",
"Steve Rader",
"Jens Rantil",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Volker Ribbert",
"Chad Robinson",
"Paul Rolland",
"Andreas Rönnquist",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Peter Sarvas",
"Oliver Schneider",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Setoh",
"Michael Shell",
"shigeri",
"Jesse Skinner",
"Ville Skyttä",
"Dale P. Smith",
"Andrea Spadaccini",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Timo Teräs",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Anders Troback",
"Tsutsui",
"Aleksandar Urošević",
"Petr Vanek",
"Jeroen Versteeg",
"Kevin Vigor",
"Johan Vromans",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"YUP",
"Daniel Zaoui",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};

==> claws-mail-3.14.1-1-aarch64.pkg.tar.xz: usr/include/claws-mail/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Andrej Kacian <andrej@kacian.sk>",
"Darko Koruga <darko@users.sf.net>",
"Charles Lehner <charles@claws-mail.org>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Paweł Pękala <c0rn@o2.pl>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Hoà Viêt Dinh",
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Werner Koch",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[ca] David Medina <opensusecatala@gmail.com>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[da] Erik P. Olsen <epodata@gmail.com>",
"[de] Thomas Bellmann <ThomasBellmann@gmx.net>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"[he] Isratine Citizen <genghiskhan@gmx.ca>",
"[hu] Páder Rezső <rezso@rezso.net>",
"[id_ID] MSulchan Darmawan <bleketux@gmail.com>",
"[it] Luigi Votta <luigi.vtt@gmail.com>",
"[nb] Petter Adsen <petter@synth.no>",
"[nl] Marcel Pol <mpol@gmx.net>",
"[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
"[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
"[tr] Numan Demirdöğen <if.gnu.linux@gmail.com>",
"[zh_TW] Mark Chang <mark.cyj@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Paweł Pękala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urošević <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"André Filipe de Assunção e Brito",
"Sergei Astanin",
"Ruslan N. Balkin",
"Andy Balaam",
"Henri Bauer",
"Didier Barvaux",
"Fabio Júnior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Sébastien Bigaret",
"Laurent Bigonville",
"Jean-Luc Biord",
"Blatinox",
"Hanno Boeck",
"Pavlo Bohmat",
"Ralf Bormann",
"H. Merijn Brand",
"Eugene Brevdo",
"Sean Buckheister",
"Anton Butanaev",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Natanael Copa",
"Jonathan Corbet",
"Christian Cornelssen",
"Palmer Dabbelt",
"George Danchev",
"Robert David",
"Kevin Day",
"Matthieu Dazy",
"Ben Deering",
"Pierric Descamps",
"Rodrigo Dias Arruda Senra",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Mikhail Efremov",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Tiago Faria",
"Alessandro Di Federico",
"Lars Persson Fink",
"Bob Forsman",
"Matthias Förste",
"Ivan Francolin Martinez",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Thierry Godefroy",
"Alex Gorbachenko",
"Michał Górny",
"Bodo Graumann",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Christian Hesse",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Richard Hughes",
"Arthur Huillet",
"Ben Hutchings",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Daniel Jakots",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"kazken3",
"WAKAI Kazunao",
"Fabian Keil",
"Martin Kluge",
"IWAMOTO Kouichi",
"Mikhail Kurinnoi",
"Abhay S. Kushwaha",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"Reed Loden",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Igor Mammedov",
"Tim Mann",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"Yotam Medini",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"Hanno Meyer-Thurow",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Gustavo Noronha Silva",
"Ales Nosek",
"Emilian Nowak",
"James Noyes",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Miquel Oliete",
"Paul Ollis",
"Fredrik Olofssen",
"Reza Pakdel",
"Richard Palo",
"Marcel Pol",
"Martin Pool",
"Quar",
"Don Quijote",
"Steve Rader",
"Jens Rantil",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Volker Ribbert",
"Chad Robinson",
"Paul Rolland",
"Andreas Rönnquist",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Peter Sarvas",
"Oliver Schneider",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Setoh",
"Michael Shell",
"shigeri",
"Jesse Skinner",
"Ville Skyttä",
"Dale P. Smith",
"Andrea Spadaccini",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Timo Teräs",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Anders Troback",
"Tsutsui",
"Aleksandar Urošević",
"Petr Vanek",
"Jeroen Versteeg",
"Kevin Vigor",
"Johan Vromans",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"YUP",
"Daniel Zaoui",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};
